pub type Cmd = Infallible;Expand description
Requests from the layer above.
Uninhabited: detection begins at initialisation and there is nothing to ask for, exactly as
crate::perfect_failure_detector has it.
Aliased Type
pub enum Cmd {}pub type Cmd = Infallible;Requests from the layer above.
Uninhabited: detection begins at initialisation and there is nothing to ask for, exactly as
crate::perfect_failure_detector has it.
pub enum Cmd {}